@@ -1,7 +1,7 @@
 /************************************************************************
  * AIPlayer.c     Code for dopewars computer players                    *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -685,7 +685,7 @@ void AISendRandomMessage(Player *AIPlay)
  * Whoops - the user asked that we run an AI player, but the binary was
  * built without that compiled in.
  */
-void AIPlayerLoop()
+void AIPlayerLoop(struct CMDLINE *cmdline)
 {
   g_print(_("This binary has been compiled without networking support, "
             "and thus cannot act as an AI player.\nRecompile passing "
