@@ -1,7 +1,7 @@
 /************************************************************************
  * admin.h        Header file for dopewars server administration        *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -27,7 +27,7 @@
 #include <config.h>
 #endif
 
-#ifndef CYGWIN
+#if !defined(CYGWIN) && defined(NETWORKING)
 
 struct CMDLINE;
 void AdminServer(struct CMDLINE *cmdline);
