@@ -1,7 +1,7 @@
 /************************************************************************
  * curses_client.c  dopewars client using the (n)curses console library *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -294,8 +294,8 @@ void display_intro(void)
                     "possible (and stay alive)!"));
   mvaddcentstr(8, _("You have one month of game time to make your fortune."));
 
-  g_string_sprintf(text, _("Version %-8s Copyright (C) 1998-2003  Ben Webb "
-                           "ben@bellatrix.pcl.ox.ac.uk"), VERSION);
+  g_string_sprintf(text, _("Version %-8s Copyright (C) 1998-2004  Ben Webb "
+                           "benwebb@users.sf.net"), VERSION);
   mvaddcentstr(10, text->str);
   g_string_assign(text, _("dopewars is released under the GNU "
                           "General Public Licence"));
@@ -2605,9 +2605,11 @@ static void Curses_DoGame(Player *Play)
     } else if (DisplayMode == DM_FIGHT) {
       switch (c) {
       case 'D':
-        DisplayMode = DM_STREET;
-        if (!(Play->Flags & FIGHTING) && HaveAbility(Play, A_DONEFIGHT)) {
-          SendClientMessage(Play, C_NONE, C_DONE, NULL, NULL);
+        if (!RunHere || fp == F_LASTLEAVE) {
+          DisplayMode = DM_STREET;
+          if (!(Play->Flags & FIGHTING) && HaveAbility(Play, A_DONEFIGHT)) {
+            SendClientMessage(Play, C_NONE, C_DONE, NULL, NULL);
+          }
         }
         break;
       case 'R':
