@@ -1,7 +1,7 @@
 /************************************************************************
  * dopewars.h     Common structures and stuff for dopewars              *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -351,7 +351,7 @@ struct GLOBALS {
   int *MaxIndex;
   void (*ResizeFunc) (int NewNum);
   gboolean Modified;
-  int MinVal;
+  int MinVal, MaxVal;
 };
 
 struct CMDLINE { 
