@@ -1,7 +1,7 @@
 /************************************************************************
  * message.c      Message-handling routines for dopewars                *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -1042,7 +1042,7 @@ int ProcessMessage(char *Msg, Player *Play, Player **Other, AICode *AI,
   pt = Msg;
   if (HaveAbility(Play, A_PLAYERID)) {
     buf = GetNextWord(&pt, NULL);
-    if (buf[0]) {
+    if (buf && buf[0]) {
       ID = atoi(buf);
       *Other = GetPlayerByID(ID, First);
     }
