@@ -1,7 +1,7 @@
 /************************************************************************
  * util.h         Miscellaneous utility and portability functions       *
- * Copyright (C)  1998-2003  Ben Webb                                   *
- *                Email: ben@bellatrix.pcl.ox.ac.uk                     *
+ * Copyright (C)  1998-2004  Ben Webb                                   *
+ *                Email: benwebb@users.sf.net                           *
  *                WWW: http://dopewars.sourceforge.net/                 *
  *                                                                      *
  * This program is free software; you can redistribute it and/or        *
@@ -38,8 +38,6 @@
 #define SIG_BLOCK     0
 #define SIG_UNBLOCK   0
 
-typedef int ssize_t;
-
 struct sigaction {
   void *sa_handler;
   int sa_flags;
